@@ -11,6 +11,7 @@ from sqlalchemy.orm                     import class_mapper
 from sqlalchemy.exc                     import InvalidRequestError
 from sqlalchemy.orm.properties          import RelationshipProperty
 from sqlalchemy                         import not_
+from sqlalchemy                         import Integer
 from zope.interface                     import providedBy
 
 import colander
@@ -141,8 +142,20 @@ def filter_query(filters, query, cls):
     return query
 
 
-def filter_list(filters, list_):
+def filter_list(filters, list_, cls):
     for column, command, args in filters['column_filters']:
+        properties = list(class_mapper(cls).iterate_properties)
+
+        type_cleaner = None
+        # figure out if we should cast the passed it variable
+        for prop in properties:
+            if prop.key == column:
+                if isinstance(prop.columns[0].type, Integer):
+                    type_cleaner = int
+
+        if type_cleaner:
+            args = type_cleaner(args)
+
         if command == 'equals':
             list_ = filter(lambda x: getattr(x, column) == args, list_)
         elif command == 'not_equals':
@@ -431,6 +444,8 @@ class JsonSerializableMixin(TraversalBase):
             p.key for p in properties if type(p) is RelationshipProperty
         ]
 
+        # attrs is the attributes that we serialize to json
+        # we store them separately since we have a blacklist
         attrs = []
         all_properties = {}
         for p in properties:
@@ -473,20 +488,21 @@ class JsonSerializableMixin(TraversalBase):
             props[key] = attr
 
         for key in relationships:
-            # get the class property value
-            attr = getattr(self, key)
-
             # let see if we need to eagerly load it
             # this is for SQLAlchemy foreign key fields that
             # indicate with one-to-many relationships
             many_directions = ["ONETOMANY", "MANYTOMANY"]
 
-            if key in json_eager_load and attr:
-                if all_properties[key].direction.name in many_directions:
-                    # jsonify all child objects
-                    props[key] = [self.try_to_json(request, x) for x in attr]
-                else:
-                    props[key] = self.try_to_json(request, attr)
+            if key in json_eager_load:
+                # get the class property value
+                attr = getattr(self, key)
+
+                if attr:
+                    if all_properties[key].direction.name in many_directions:
+                        # jsonify all child objects
+                        props[key] = [self.try_to_json(request, x) for x in attr]
+                    else:
+                        props[key] = self.try_to_json(request, attr)
 
         return props
 
@@ -616,7 +632,16 @@ class TraversalMixin(JsonSerializableMixin):
                 if not isinstance(obj, ignore_types):
                     # is this is a collection
                     iter(obj)
-                    col = ModelCollection(filter_list(filters, obj))
+
+                    properties = list(class_mapper(type(self)).iterate_properties)
+
+                    rel_cls = None
+
+                    for prop in properties:
+                        if prop.key == table_name:
+                            rel_cls = prop.mapper.class_
+
+                    col = ModelCollection(filter_list(filters, obj, rel_cls))
                     col.__parent__ = self
 
                     if request:
